@@ -61,6 +61,11 @@ type Watcher struct {
 	// config sourcing.
 	plugins map[string]*plugin.Instance
 
+	// originalEnv is a set of original environment variables. If an
+	// env var is unset but is available here, then we use this original value
+	// instead.
+	originalEnv []string
+
 	// inSourceCh and inVarCh are the channels that are used to send
 	// updated sets of configuration sources and variables to the watch loop.
 	inSourceCh chan []*pb.ConfigSource
@@ -460,7 +465,9 @@ func (w *Watcher) watcher(
 			// If we didn't send the env previously OR the new env is different
 			// than the old env, then we send these env vars.
 			if !prevEnvSent || !reflect.DeepEqual(prevEnv, newEnv) {
+				newEnv, deletedEnv := calculateDeletedEnv(newEnv, prevEnv, w.originalEnv)
 				uc.EnvVars = newEnv
+				uc.DeletedEnvVars = deletedEnv
 				uc.UpdatedEnv = true
 			}
 
@@ -759,6 +766,8 @@ func buildAppConfig(
 	// Ininitialize our result with the static values
 	var envVars []string
 
+	var dynamicFiles []*FileContent
+
 	// Go through each and read our configurations. Note that ConfigSourcers
 	// are documented to note that Read will be called frequently so caching
 	// is expected within the sourcer itself.
@@ -826,9 +835,15 @@ func buildAppConfig(
 				if req.cv.Internal {
 					internal[req.req.Name] = cty.StringVal(r.Value)
 				} else {
-					envVars = append(envVars, req.req.Name+"="+r.Value)
-
-					env[req.req.Name] = cty.StringVal(r.Value)
+					if req.cv.NameIsPath {
+						dynamicFiles = append(dynamicFiles, &FileContent{
+							Path: req.req.Name,
+							Data: []byte(r.Value),
+						})
+					} else {
+						envVars = append(envVars, req.req.Name+"="+r.Value)
+						env[req.req.Name] = cty.StringVal(r.Value)
+					}
 				}
 
 			case *sdkpb.ConfigSource_Value_Error:
@@ -862,7 +877,7 @@ func buildAppConfig(
 
 	staticEnv, staticFiles := expandStaticVars(log, &ectx, staticVars)
 
-	return append(envVars, staticEnv...), staticFiles
+	return append(envVars, staticEnv...), append(staticFiles, dynamicFiles...)
 }
 
 // expandStaticVars will parse any value that appears to be a HCL template as one and then
@@ -921,3 +936,49 @@ func expandStaticVars(
 
 	return envVars, files
 }
+
+// calcluateDeletedEnv calculates the env vars that are deleted. This also
+// can take a list of original env vars and use that to update the new env
+// to include original values for unset. If you only want to know what is unset,
+// then set originalEnv to nil.
+func calculateDeletedEnv(newEnv, prevEnv, originalEnv []string) ([]string, []string) {
+	newMap := envListToMap(newEnv)
+	prevMap := envListToMap(prevEnv)
+	origMap := envListToMap(originalEnv)
+
+	// deleted is the list of env var keys that are full unset
+	var deleted []string
+
+	// Find all the values that are removed from the new map.
+	for k := range prevMap {
+		// If we have it in the new map, then we still have it. Not deleted.
+		if _, ok := newMap[k]; ok {
+			continue
+		}
+
+		// If we have it in the original, then use that value.
+		if v, ok := origMap[k]; ok {
+			newEnv = append(newEnv, k+"="+v)
+			continue
+		}
+
+		// It is deleted.
+		deleted = append(deleted, k)
+	}
+
+	return newEnv, deleted
+}
+
+func envListToMap(v []string) map[string]string {
+	result := map[string]string{}
+	for _, str := range v {
+		idx := strings.Index(str, "=")
+		if idx == -1 {
+			continue
+		}
+
+		result[str[:idx]] = str[idx+1:]
+	}
+
+	return result
+}
