@@ -49,6 +49,7 @@ var (
 	// hiddenCommands are not shown in CLI help output.
 	hiddenCommands = map[string]struct{}{
 		"plugin": {},
+		"k8s":    {},
 
 		// Deprecated:
 		"token": {}, // replaced by "user"
@@ -463,6 +464,11 @@ func Commands(
 				baseCommand: baseCommand,
 			}, nil
 		},
+		"context set": func() (cli.Command, error) {
+			return &ContextSetCommand{
+				baseCommand: baseCommand,
+			}, nil
+		},
 
 		"ui": func() (cli.Command, error) {
 			return &UICommand{
@@ -566,12 +572,57 @@ func Commands(
 				baseCommand: baseCommand,
 			}, nil
 		},
-
 		"user token": func() (cli.Command, error) {
 			return &UserTokenCommand{
 				baseCommand: baseCommand,
 			}, nil
 		},
+		"runner profile": func() (cli.Command, error) {
+			return &helpCommand{
+				SynopsisText: helpText["runner-profile"][0],
+				HelpText:     helpText["runner-profile"][1],
+			}, nil
+		},
+
+		"runner profile set": func() (cli.Command, error) {
+			return &RunnerProfileSetCommand{
+				baseCommand: baseCommand,
+			}, nil
+		},
+
+		"runner profile inspect": func() (cli.Command, error) {
+			return &RunnerProfileInspectCommand{
+				baseCommand: baseCommand,
+			}, nil
+		},
+
+		"runner profile list": func() (cli.Command, error) {
+			return &RunnerProfileListCommand{
+				baseCommand: baseCommand,
+			}, nil
+		},
+
+		"k8s bootstrap": func() (cli.Command, error) {
+			return &K8SBootstrapCommand{
+				baseCommand: baseCommand,
+			}, nil
+		},
+		"workspace": func() (cli.Command, error) {
+			return &helpCommand{
+				SynopsisText: helpText["workspace"][0],
+				HelpText:     helpText["workspace"][1],
+			}, nil
+		},
+		"workspace inspect": func() (cli.Command, error) {
+			return &WorkspaceInspectCommand{
+				baseCommand: baseCommand,
+			}, nil
+		},
+		"workspace list": func() (cli.Command, error) {
+			return &WorkspaceListCommand{
+				baseCommand: baseCommand,
+			}, nil
+		},
 	}
 
 	// register our aliases
@@ -609,12 +660,20 @@ func logger(args []string) ([]string, hclog.Logger, io.Writer, error) {
 	// Process arguments looking for `-v` flags to control the log level.
 	// This overrides whatever the env var set.
 	var outArgs []string
-	for _, arg := range args {
+	for i, arg := range args {
 		if len(arg) != 0 && arg[0] != '-' {
 			outArgs = append(outArgs, arg)
 			continue
 		}
 
+		// If we hit a break indicating pass-through flags, we add them all to
+		// outArgs and just exit, since we don't want to process any secondary
+		//  `-v` flags at this time.
+		if arg == "--" {
+			outArgs = append(outArgs, args[i:]...)
+			break
+		}
+
 		switch arg {
 		case "-v":
 			if level == hclog.NoLevel || level > hclog.Info {
@@ -908,6 +967,21 @@ about the currently logged in user, generate new access, and invite new
 users directly into the Waypoint server.
 
 If you are looking to log in to Waypoint, use "waypoint login".
+`,
+	},
+	"runner-profile": {
+		"Manage runner profiles",
+		`
+List and edit runner profiles
+
+Each runner profile entry represents the ability to spawn
+runners (i.e. on-demand runners) when needed using the configured plugin.
+`,
+	},
+	"workspace": {
+		"Manage workspaces",
+		`
+List and inspect Workspaces for this context.
 `,
 	},
 }
