@@ -464,7 +464,7 @@ func (c *StatusCommand) FormatProjectAppStatus(projectTarget string) error {
 			return err
 		}
 
-		if appDeployStatus != nil {
+		if appDeployStatus != nil && appDeployStatus.Health != nil {
 			if appDeployStatus.Health.HealthStatus == "ERROR" ||
 				appDeployStatus.Health.HealthStatus == "DOWN" {
 				appFailures = true
@@ -503,9 +503,9 @@ func (c *StatusCommand) FormatProjectAppStatus(projectTarget string) error {
 			return err
 		}
 
-		if appReleaseStatus != nil {
-			if appDeployStatus.Health.HealthStatus == "ERROR" ||
-				appDeployStatus.Health.HealthStatus == "DOWN" {
+		if appReleaseStatus != nil && appReleaseStatus.Health != nil {
+			if appReleaseStatus.Health.HealthStatus == "ERROR" ||
+				appReleaseStatus.Health.HealthStatus == "DOWN" {
 				appFailures = true
 			}
 		}
@@ -848,21 +848,16 @@ func (c *StatusCommand) FormatAppStatus(projectTarget string, appTarget string)
 	if c.flagJson {
 		c.outputJsonAppStatus(appTbl, deployTbl, resourcesTbl, releaseTbl, releaseResourcesTbl, project)
 	} else {
-		c.ui.Output("")
 		c.ui.Output("Application Summary", terminal.WithHeaderStyle())
 		c.ui.Table(appTbl, terminal.WithStyle("Simple"))
-		c.ui.Output("")
 		c.ui.Output("Deployment Summary", terminal.WithHeaderStyle())
 		c.ui.Table(deployTbl, terminal.WithStyle("Simple"))
-		c.ui.Output("")
 		c.ui.Output("Deployment Resources Summary", terminal.WithHeaderStyle())
 		c.ui.Table(resourcesTbl, terminal.WithStyle("Simple"))
-		c.ui.Output("")
 
 		if !releaseUnimplemented {
 			c.ui.Output("Release Summary", terminal.WithHeaderStyle())
 			c.ui.Table(releaseTbl, terminal.WithStyle("Simple"))
-			c.ui.Output("")
 			c.ui.Output("Release Resources Summary", terminal.WithHeaderStyle())
 			c.ui.Table(releaseResourcesTbl, terminal.WithStyle("Simple"))
 			c.ui.Output("")
@@ -872,8 +867,6 @@ func (c *StatusCommand) FormatAppStatus(projectTarget string, appTarget string)
 	}
 
 	if appFailures {
-		c.ui.Output("")
-
 		c.ui.Output(wpStatusHealthTriageMsg, projectTarget, terminal.WithWarningStyle())
 	}
 
@@ -1179,16 +1172,20 @@ func (c *StatusCommand) getWorkspaceFromProject(pr *pb.GetProjectResponse) (stri
 	var workspace string
 
 	if len(pr.Workspaces) != 0 {
-		if c.flagWorkspace != "" {
+		wp, err := c.workspace()
+		if err != nil {
+			return "", err
+		}
+		if wp != "" {
 			for _, ws := range pr.Workspaces {
-				if ws.Workspace.Workspace == c.flagWorkspace {
+				if ws.Workspace.Workspace == wp {
 					workspace = ws.Workspace.Workspace
 					break
 				}
 			}
 
 			if workspace == "" {
-				return "", fmt.Errorf("Failed to find project in requested workspace %q", c.flagWorkspace)
+				return "", fmt.Errorf("Failed to find project in requested workspace %q", wp)
 			}
 		} else {
 			// No workspace flag specified, try the "first" one
@@ -1351,7 +1348,7 @@ their current state, run ‘waypoint status -app=APP-NAME PROJECT-NAME’.
 `)
 
 	wpStatusAppSuccessMsg = strings.TrimSpace(`
-The application and its declared resources listed above represents its current state known
+The application and its resources listed above represents its current state known
 in the Waypoint server.
 `)
 
@@ -1384,7 +1381,7 @@ waypoint status -app=APP-NAME %[1]s
 `)
 
 	wpProjectNotFound = strings.TrimSpace(`
-No project name %q was found for the server context %q. To see a list of
+No project named %q was found for the server context %q. To see a list of
 currently configured projects, run “waypoint project list”.
 
 If you want more information for a specific application, use the '-app' flag
