@@ -8,8 +8,8 @@ import (
 	"path/filepath"
 	"time"
 
-	"github.com/boltdb/bolt"
 	"github.com/golang/protobuf/ptypes/empty"
+	bolt "go.etcd.io/bbolt"
 	"google.golang.org/grpc"
 
 	"github.com/hashicorp/waypoint/internal/protocolversion"
@@ -102,6 +102,7 @@ func (c *Project) initLocalServer(ctx context.Context) (*grpc.ClientConn, error)
 	impl, err := singleprocess.New(
 		singleprocess.WithDB(db),
 		singleprocess.WithLogger(log.Named("singleprocess")),
+		singleprocess.WithSuperuser(), // local mode has no auth
 	)
 	if err != nil {
 		return nil, err
