@@ -5,6 +5,7 @@ import (
 
 	"github.com/golang/protobuf/ptypes/empty"
 	"github.com/hashicorp/go-hclog"
+	"go.opencensus.io/plugin/ocgrpc"
 	"google.golang.org/grpc"
 	"google.golang.org/grpc/keepalive"
 	"google.golang.org/grpc/reflection"
@@ -62,6 +63,12 @@ func newGrpcServer(opts *options) (*grpcServer, error) {
 		)
 	}
 
+	// This is the only place we wire telemetry into our grpc server.
+	if opts.TelemetryEnabled {
+		log.Debug("Enabling server ocgrpc stats handler")
+		so = append(so, grpc.StatsHandler(&ocgrpc.ServerHandler{}))
+	}
+
 	s := grpc.NewServer(so...)
 
 	return &grpcServer{
@@ -75,7 +82,7 @@ func newGrpcServer(opts *options) (*grpcServer, error) {
 func (s *grpcServer) start() error {
 	// Register the reflection service. This makes using tools like grpcurl
 	// easier. It makes it slightly easier for malicious users to know about
-	// the service but I think they'd figure out its a waypoint server
+	// the service but I think they'd figure out it's a waypoint server
 	// easy enough.
 	reflection.Register(s.server)
 
