@@ -1,6 +1,9 @@
 import Route from '@ember/routing/route';
 import { Project } from 'waypoint-pb';
 import { Breadcrumb } from 'waypoint/services/breadcrumbs';
+import Controller from 'waypoint/controllers/workspace/projects/new';
+
+type Model = Project.AsObject;
 
 export default class WorkspaceProjectsNew extends Route {
   breadcrumbs: Breadcrumb[] = [
@@ -14,12 +17,12 @@ export default class WorkspaceProjectsNew extends Route {
     },
   ];
 
-  model() {
+  model(): Model {
     let proj = new Project();
     return proj.toObject();
   }
 
-  resetController(controller, isExiting) {
+  resetController(controller: Controller, isExiting: boolean): void {
     if (isExiting) {
       controller.set('createGit', false);
     }
