@@ -1,3 +1,3 @@
-export default function login(token?: string) {
+export default function login(token?: string): void {
   window.localStorage.waypointAuthToken = token || 'default-test-token-value';
 }
